# Container API

::: wd.di.container.ServiceProvider
    handler: python
    options:
      show_root_heading: true
      show_source: false

::: wd.di.container.Scope
    handler: python
    options:
      show_root_heading: true
      show_source: false 